@@ -110,9 +110,9 @@ namespace gnote {
     return Glib::RefPtr<Gio::SimpleAction>();
   }
 
-  Glib::RefPtr<Gio::SimpleAction> ActionManager::add_app_action(const Glib::ustring & name)
+  Glib::RefPtr<Gio::SimpleAction> ActionManager::add_app_action(Glib::ustring && name)
   {
-    Glib::RefPtr<Gio::SimpleAction> action = Gio::SimpleAction::create(name);
+    auto action = Gio::SimpleAction::create(std::move(name));
     m_app_actions.push_back(action);
     return action;
   }
@@ -184,7 +184,7 @@ namespace gnote {
   void ActionManager::add_app_menu_items(std::vector<PopoverWidget> & widgets)
   {
     for(auto& iter : m_app_menu_items) {
-      widgets.push_back(PopoverWidget(iter.first, iter.second.order, utils::create_popover_button(iter.second.action_def, iter.second.label)));
+      widgets.push_back(PopoverWidget(iter.first, iter.second.order, utils::create_popover_button(iter.second.action_def, Glib::ustring(iter.second.label))));
     }
   }
 
