@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013,2016-2017 Aurimas Cernius
+ * Copyright (C) 2013,2016-2017,2019 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,12 +21,21 @@
 #define _IGNOTE_HPP_
 
 #include "mainwindow.hpp"
-#include "base/singleton.hpp"
 
 namespace gnote {
 
+class IActionManager;
+class IconManager;
+class Preferences;
+namespace notebooks {
+  class NotebookManager;
+}
+namespace sync {
+  class ISyncManager;
+}
+
+
 class IGnote
-  : public base::Singleton<IGnote>
 {
 public:
   static Glib::ustring cache_dir();
@@ -35,6 +44,13 @@ public:
   static Glib::ustring old_note_dir();
 
   virtual ~IGnote();
+
+  virtual IActionManager & action_manager() = 0;
+  virtual IconManager & icon_manager() = 0;
+  virtual notebooks::NotebookManager & notebook_manager() = 0;
+  virtual sync::ISyncManager & sync_manager() = 0;
+  virtual Preferences & preferences() = 0;
+
   virtual MainWindow & get_main_window() = 0;
   virtual MainWindow & get_window_for_note() = 0;
   virtual MainWindow & new_main_window() = 0;
