@@ -1,7 +1,7 @@
  /*
  * gnote
  *
- * Copyright (C) 2010-2017,2019-2022 Aurimas Cernius
+ * Copyright (C) 2010-2017,2019-2023 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -76,6 +76,7 @@ namespace gnote {
 
       button = manage(new Gtk::Button(_("_Delete"), true));
       button->property_can_default().set_value(true);
+      button->get_style_context()->add_class("destructive-action");
       button->show ();
       dialog.add_action_widget(*button, 666);
 
@@ -135,8 +136,8 @@ namespace gnote {
 
   const int  NoteData::s_noPosition = -1;
 
-  NoteData::NoteData(const Glib::ustring & _uri)
-    : m_uri(_uri)
+  NoteData::NoteData(Glib::ustring && _uri)
+    : m_uri(std::move(_uri))
     , m_cursor_pos(s_noPosition)
     , m_selection_bound_pos(s_noPosition)
     , m_width(0)
@@ -159,9 +160,9 @@ namespace gnote {
     return (m_width != 0) && (m_height != 0);
   }
 
-  void NoteDataBufferSynchronizer::set_buffer(const Glib::RefPtr<NoteBuffer> & b)
+  void NoteDataBufferSynchronizer::set_buffer(Glib::RefPtr<NoteBuffer> && b)
   {
-    m_buffer = b;
+    m_buffer = std::move(b);
     m_buffer->signal_changed().connect(sigc::mem_fun(*this, &NoteDataBufferSynchronizer::buffer_changed));
     m_buffer->signal_apply_tag()
       .connect(sigc::mem_fun(*this, &NoteDataBufferSynchronizer::buffer_tag_applied));
@@ -179,9 +180,9 @@ namespace gnote {
     return data().text();
   }
 
-  void NoteDataBufferSynchronizer::set_text(const Glib::ustring & t)
+  void NoteDataBufferSynchronizer::set_text(Glib::ustring && t)
   {
-    data().text() = t;
+    data().text() = std::move(t);
     synchronize_buffer();
   }
 
@@ -246,8 +247,8 @@ namespace gnote {
     }
   }
 
-  Note::Note(std::unique_ptr<NoteData> _data, const Glib::ustring & filepath, NoteManager & _manager, IGnote & g)
-    : NoteBase(filepath, _manager)
+  Note::Note(std::unique_ptr<NoteData> _data, Glib::ustring && filepath, NoteManager & _manager, IGnote & g)
+    : NoteBase(std::move(filepath), _manager)
     , m_gnote(g)
     , m_data(std::move(_data))
     , m_save_needed(false)
@@ -270,21 +271,18 @@ namespace gnote {
     delete m_window;
   }
 
-  Note::Ptr Note::create_new_note(const Glib::ustring & title,
-                                  const Glib::ustring & filename,
-                                  NoteManager & manager,
-                                  IGnote & g)
+  Note::Ptr Note::create_new_note(Glib::ustring && title, Glib::ustring && filename, NoteManager & manager, IGnote & g)
   {
     auto note_data = std::make_unique<NoteData>(url_from_path(filename));
-    note_data->title() = title;
+    note_data->title() = std::move(title);
     auto date(Glib::DateTime::create_now_local());
     note_data->create_date() = date;
     note_data->set_change_date(date);
       
-    return std::make_shared<Note>(std::move(note_data), filename, manager, g);
+    return std::make_shared<Note>(std::move(note_data), std::move(filename), manager, g);
   }
 
-  Note::Ptr Note::create_existing_note(std::unique_ptr<NoteData> data, Glib::ustring filepath, NoteManager & manager, IGnote & g)
+  Note::Ptr Note::create_existing_note(std::unique_ptr<NoteData> data, Glib::ustring && filepath, NoteManager & manager, IGnote & g)
   {
     if (!data->change_date()) {
       auto d(sharp::file_modification_time(filepath));
@@ -299,7 +297,7 @@ namespace gnote {
         data->create_date() = d;
       }
     }
-    return std::make_shared<Note>(std::move(data), filepath, manager, g);
+    return std::make_shared<Note>(std::move(data), std::move(filepath), manager, g);
   }
 
   void Note::delete_note()
@@ -326,11 +324,11 @@ namespace gnote {
   }
 
   
-  Note::Ptr Note::load(const Glib::ustring & read_file, NoteManager & manager, IGnote & g)
+  Note::Ptr Note::load(Glib::ustring && read_file, NoteManager & manager, IGnote & g)
   {
     auto data = std::make_unique<NoteData>(url_from_path(read_file));
     manager.note_archiver().read_file(read_file, *data);
-    return create_existing_note(std::move(data), read_file, manager, g);
+    return create_existing_note(std::move(data), std::move(read_file), manager, g);
   }
 
   
@@ -477,10 +475,9 @@ namespace gnote {
     queue_save(OTHER_DATA_CHANGED);
   }
 
-  void Note::add_child_widget(const Glib::RefPtr<Gtk::TextChildAnchor> & child_anchor,
-                              Gtk::Widget * widget)
+  void Note::add_child_widget(Glib::RefPtr<Gtk::TextChildAnchor> && child_anchor, Gtk::Widget *widget)
   {
-    m_child_widget_queue.push(ChildWidgetData(child_anchor, widget));
+    m_child_widget_queue.push(ChildWidgetData(std::move(child_anchor), widget));
     if(has_window()) {
       process_child_widget_queue();
     }
@@ -500,16 +497,15 @@ namespace gnote {
     }
   }
 
-  void Note::set_title(const Glib::ustring & new_title,
-                       bool from_user_action)
+  void Note::set_title(Glib::ustring && new_title, bool from_user_action)
   {
     if (m_data.data().title() != new_title) {
       if (m_window) {
-        m_window->set_name(new_title);
+        m_window->set_name(Glib::ustring(new_title));
       }
 
-      Glib::ustring old_title = m_data.data().title();
-      m_data.data().title() = new_title;
+      Glib::ustring old_title = std::move(m_data.data().title());
+      m_data.data().title() = std::move(new_title);
 
       if (from_user_action) {
         process_rename_link_update(old_title);
@@ -609,7 +605,7 @@ namespace gnote {
     const NoteTag::Ptr link_tag = m_tag_table->get_link_tag();
 
     // Replace existing links with the new title.
-    utils::TextTagEnumerator enumerator(m_buffer, link_tag);
+    utils::TextTagEnumerator enumerator(get_buffer(), link_tag);
     while (enumerator.move_next()) {
       const utils::TextRange & range(enumerator.current());
       if (range.text().lowercase() != old_title_lower)
@@ -634,24 +630,24 @@ namespace gnote {
     }
   }
 
-  void Note::rename_without_link_update(const Glib::ustring & newTitle)
+  void Note::rename_without_link_update(Glib::ustring && newTitle)
   {
     if(data_synchronizer().data().title() != newTitle) {
       if(m_window) {
-        m_window->set_name(newTitle);
+        m_window->set_name(Glib::ustring(newTitle));
       }
     }
-    NoteBase::rename_without_link_update(newTitle);
+    NoteBase::rename_without_link_update(std::move(newTitle));
   }
 
-  void Note::set_xml_content(const Glib::ustring & xml)
+  void Note::set_xml_content(Glib::ustring && xml)
   {
     if (m_buffer) {
       m_buffer->set_text("");
-      NoteBufferArchiver::deserialize(m_buffer, xml);
+      NoteBufferArchiver::deserialize(m_buffer, std::move(xml));
     } 
     else {
-      NoteBase::set_xml_content(xml);
+      NoteBase::set_xml_content(std::move(xml));
     }
   }
 
@@ -663,10 +659,10 @@ namespace gnote {
     return m_buffer->get_slice(m_buffer->begin(), m_buffer->end());
   }
 
-  void Note::set_text_content(const Glib::ustring & text)
+  void Note::set_text_content(Glib::ustring && text)
   {
     if(m_buffer) {
-      m_buffer->set_text(text);
+      m_buffer->set_text(std::move(text));
     }
     else {
       ERR_OUT(_("Setting text content for closed notes not supported"));
@@ -689,7 +685,7 @@ namespace gnote {
     if(!m_buffer) {
       DBG_OUT("Creating buffer for %s", m_data.data().title().c_str());
       m_buffer = NoteBuffer::create(get_tag_table(), *this, m_gnote.preferences());
-      m_data.set_buffer(m_buffer);
+      m_data.set_buffer(Glib::RefPtr<NoteBuffer>(m_buffer));
 
       m_buffer->signal_changed().connect(
         sigc::mem_fun(*this, &Note::on_buffer_changed));
