@@ -147,10 +147,7 @@ namespace gnote {
   {
     // TODO: Is this variables used, or do we just need to
     // access iter.Tags to work around a bug?
-    Glib::SListHandle<Glib::RefPtr<const Gtk::TextTag> > tag_list = iter.get_tags();
-    for(Glib::SListHandle<Glib::RefPtr<const Gtk::TextTag> >::const_iterator tag_iter = tag_list.begin();
-        tag_iter != tag_list.end(); ++tag_iter) {
-      const Glib::RefPtr<const Gtk::TextTag> & tag(*tag_iter);
+    for(const auto & tag : iter.get_tags()) {
       DynamicNoteTag::ConstPtr dynamic_tag =  DynamicNoteTag::ConstPtr::cast_dynamic(tag);
       if (dynamic_tag &&
           (dynamic_tag->get_element_name() == tag_name)) {
@@ -184,10 +181,7 @@ namespace gnote {
     else {
       // Remove any existing tags when a depth tag is applied
       m_undomanager->freeze_undo();
-      Glib::SListHandle<Glib::RefPtr<const Gtk::TextTag> > tag_list = start_char.get_tags();
-      for(Glib::SListHandle<Glib::RefPtr<const Gtk::TextTag> >::const_iterator tag_iter = tag_list.begin();
-          tag_iter != tag_list.end(); ++tag_iter) {
-        const Glib::RefPtr<const Gtk::TextTag> & tag(*tag_iter);
+      for(const auto & tag : start_char.get_tags()) {
         DepthNoteTag::ConstPtr dn_tag2 = DepthNoteTag::ConstPtr::cast_dynamic(tag);
         if (!dn_tag2) {
           // here it gets hairy. Gtkmm does not implement remove_tag() on a const.
@@ -277,10 +271,8 @@ namespace gnote {
         insert_start.backward_chars (text.size());
 
         m_undomanager->freeze_undo();
-        Glib::SListHandle<Glib::RefPtr<Gtk::TextTag> > tag_list = insert_start.get_tags();
-        for(Glib::SListHandle<Glib::RefPtr<Gtk::TextTag> >::const_iterator tag_iter = tag_list.begin();
-            tag_iter != tag_list.end(); ++tag_iter) {
-          remove_tag(*tag_iter, insert_start, pos);
+        for(const auto & tag : insert_start.get_tags()) {
+          remove_tag(tag, insert_start, pos);
         }
 
         for(auto & tag : m_active_tags) {
@@ -676,20 +668,14 @@ namespace gnote {
     Gtk::TextIter iter = get_iter_at_mark(mark);
 
     // Add any growable tags not starting on the next character...
-    const Glib::SListHandle<Glib::RefPtr<Gtk::TextTag> > tag_list(iter.get_tags());
-    for(Glib::SListHandle<Glib::RefPtr<Gtk::TextTag> >::const_iterator tag_iter = tag_list.begin();
-        tag_iter != tag_list.end(); ++tag_iter) {
-      const Glib::RefPtr<Gtk::TextTag> & tag(*tag_iter);
+    for(const auto & tag : iter.get_tags()) {
       if(!iter.starts_tag(tag) && NoteTagTable::tag_is_growable(tag)) {
         m_active_tags.push_back(tag);
       }
     }
 
     // Add any growable tags not ending on the prior character..
-    const Glib::SListHandle<Glib::RefPtr<Gtk::TextTag> > tag_list2(iter.get_toggled_tags(false));
-    for(Glib::SListHandle<Glib::RefPtr<Gtk::TextTag> >::const_iterator tag_iter = tag_list2.begin();
-        tag_iter != tag_list2.end(); ++tag_iter) {
-      const Glib::RefPtr<Gtk::TextTag> & tag(*tag_iter);
+    for(const auto & tag : iter.get_toggled_tags(false)) {
       if (!iter.ends_tag(tag) && NoteTagTable::tag_is_growable(tag)) {
         m_active_tags.push_back(tag);
       }
@@ -1043,10 +1029,7 @@ namespace gnote {
   {
     DepthNoteTag::Ptr depth_tag;
 
-    Glib::SListHandle<Glib::RefPtr<Gtk::TextTag> > tag_list = iter.get_tags();
-    for(Glib::SListHandle<Glib::RefPtr<Gtk::TextTag> >::const_iterator tag_iter = tag_list.begin();
-        tag_iter != tag_list.end(); ++tag_iter) {
-      const Glib::RefPtr<Gtk::TextTag> & tag(*tag_iter);
+    for(const auto & tag : iter.get_tags()) {
       if (NoteTagTable::tag_has_depth (tag)) {
         depth_tag = DepthNoteTag::Ptr::cast_dynamic(tag);
         break;
@@ -1142,10 +1125,7 @@ namespace gnote {
                                "http://beatniksoftware.com/tomboy/size");
 
     // Insert any active tags at start into tag_stack...
-    Glib::SListHandle<Glib::RefPtr<const Gtk::TextTag> > tag_list = start.get_tags();
-    for(Glib::SListHandle<Glib::RefPtr<const Gtk::TextTag> >::const_iterator tag_iter = tag_list.begin();
-        tag_iter != tag_list.end(); ++tag_iter) {
-      const Glib::RefPtr<const Gtk::TextTag> & start_tag(*tag_iter);
+    for(const auto & start_tag : start.get_tags()) {
       if (!start.toggles_tag (start_tag)) {
         tag_stack.push (start_tag);
         write_tag (start_tag, xml, true);
@@ -1209,10 +1189,7 @@ namespace gnote {
       }
 
       // Output any tags that begin at the current position
-      Glib::SListHandle<Glib::RefPtr<Gtk::TextTag> > tag_list2 = iter.get_tags();
-      for(Glib::SListHandle<Glib::RefPtr<Gtk::TextTag> >::const_iterator tag_iter = tag_list2.begin();
-          tag_iter != tag_list2.end(); ++tag_iter) {
-        const Glib::RefPtr<Gtk::TextTag> & tag(*tag_iter);
+      for(const auto& tag : iter.get_tags()) {
         if(iter.starts_tag(tag)) {
           if (!(DepthNoteTag::Ptr::cast_dynamic(tag)) && NoteTagTable::tag_is_serializable(tag)) {
             write_tag (tag, xml, true);
@@ -1285,10 +1262,7 @@ namespace gnote {
         }
       } 
       else {
-        Glib::SListHandle<Glib::RefPtr<Gtk::TextTag> > tag_list3 = iter.get_tags();
-        for(Glib::SListHandle<Glib::RefPtr<Gtk::TextTag> >::const_iterator tag_iter = tag_list3.begin();
-            tag_iter != tag_list3.end(); ++tag_iter) {
-          const Glib::RefPtr<Gtk::TextTag> & tag(*tag_iter);
+        for(const auto& tag : iter.get_tags()) {
           if (tag_ends_here (tag, iter, next_iter) &&
               NoteTagTable::tag_is_serializable(tag) && !(DepthNoteTag::Ptr::cast_dynamic(tag)))
           {
