@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2017,2019-2022 Aurimas Cernius
+ * Copyright (C) 2010-2017,2019-2023 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -72,7 +72,6 @@ protected:
   virtual void on_show() override;
   virtual bool on_map_event(GdkEventAny *evt) override;
 private:
-  void on_open_note(const Note::Ptr &);
   void on_open_note_new_window(const Note::Ptr &);
   void on_delete_note();
   bool on_delete(GdkEventAny *);
@@ -108,6 +107,7 @@ private:
   void unregister_callbacks();
   void next_tab();
   void previous_tab();
+  void close_current_tab();
 
   IGnote             &m_gnote;
   NoteManagerBase    &m_note_manager;
